@@ -1,5 +1,5 @@
 import contextlib, datetime, os, pathlib, subprocess, tempfile, time, unittest
-from job_lock import clean_up_old_job_locks, JobLock, JobLockAndWait, jobinfo
+from job_lock import clean_up_old_job_locks, JobLock, JobLockAndWait, jobinfo, MultiJobLock
 
 class TestJobLock(unittest.TestCase, contextlib.ExitStack):
   def __init__(self, *args, **kwargs):
@@ -26,6 +26,27 @@ class TestJobLock(unittest.TestCase, contextlib.ExitStack):
       with JobLock(self.tmpdir/"lock1.lock") as lock3:
         self.assertFalse(lock3)
 
+  def testMultiJobLock(self):
+    fn1 = self.tmpdir/"lock1.lock"
+    fn2 = self.tmpdir/"lock2.lock"
+
+    with MultiJobLock(fn1, fn2) as locks:
+      self.assertTrue(locks)
+      self.assertTrue(fn1.exists())
+      self.assertTrue(fn2.exists())
+
+    with JobLock(fn1):
+      with MultiJobLock(fn1, fn2) as locks:
+        self.assertFalse(locks)
+        self.assertTrue(fn1.exists())
+        self.assertFalse(fn2.exists())
+
+    with JobLock(fn2):
+      with MultiJobLock(fn1, fn2) as locks:
+        self.assertFalse(locks)
+        self.assertFalse(fn1.exists())
+        self.assertTrue(fn2.exists())
+
   def testRunningJobs(self):
     jobtype, cpuid, jobid = jobinfo()
     with open(self.tmpdir/"lock1.lock", "w") as f:
@@ -117,12 +138,12 @@ class TestJobLock(unittest.TestCase, contextlib.ExitStack):
       self.assertEqual(lock2.niterations, 2)
 
   def testCorruptFileTimeout(self):
-    with open(self.tmpdir/"lock1.lock_2", "w") as f: pass
-    with open(self.tmpdir/"lock1.lock_5", "w") as f: pass
-    with open(self.tmpdir/"lock1.lock_30", "w") as f: pass
+    with open(self.tmpdir/"lock1.lock_2", "w"): pass
+    with open(self.tmpdir/"lock1.lock_5", "w"): pass
+    with open(self.tmpdir/"lock1.lock_30", "w"): pass
     time.sleep(1)
-    with open(self.tmpdir/"lock1.lock_10", "w") as f: pass
-    with open(self.tmpdir/"lock1.lock", "w") as f: pass
+    with open(self.tmpdir/"lock1.lock_10", "w"): pass
+    with open(self.tmpdir/"lock1.lock", "w"): pass
     with JobLock(self.tmpdir/"lock1.lock", corruptfiletimeout=datetime.timedelta(seconds=1)) as lock:
       self.assertFalse(lock)
     self.assertFalse((self.tmpdir/"lock1.lock_2").exists())
@@ -141,11 +162,11 @@ class TestJobLock(unittest.TestCase, contextlib.ExitStack):
     self.assertFalse((self.tmpdir/"lock1.lock_30").exists())
 
   def testCleanUp(self):
-    with open(self.tmpdir/"lock1.lock_2", "w") as f: pass
-    with open(self.tmpdir/"lock1.lock_5", "w") as f: pass
-    with open(self.tmpdir/"lock1.lock_30", "w") as f: pass
+    with open(self.tmpdir/"lock1.lock_2", "w"): pass
+    with open(self.tmpdir/"lock1.lock_5", "w"): pass
+    with open(self.tmpdir/"lock1.lock_30", "w"): pass
     time.sleep(1)
-    with open(self.tmpdir/"lock1.lock_10", "w") as f: pass
+    with open(self.tmpdir/"lock1.lock_10", "w"): pass
     clean_up_old_job_locks(self.tmpdir, howold=datetime.timedelta(seconds=1), dryrun=True)
     self.assertTrue((self.tmpdir/"lock1.lock_2").exists())
     self.assertTrue((self.tmpdir/"lock1.lock_5").exists())
